@@ -19,7 +19,9 @@ import logging
 import os
 import sys
 import argparse
+import traceback
 import weka.core.jvm as jvm
+import weka.core.serialization as serialization
 from weka.core.classes import OptionHandler, join_options
 from weka.core.capabilities import Capabilities
 from weka.core.converters import Loader
@@ -176,6 +178,34 @@ class Filter(OptionHandler):
                 "weka/filters/Filter", "makeCopy",
                 "(Lweka/filters/Filter;)Lweka/filters/Filter;", flter.jobject))
 
+    @classmethod
+    def deserialize(cls, ser_file):
+        """
+        Deserializes a filter from a file.
+
+        :param ser_file: the file to deserialize from
+        :type ser_file: str
+        :return: model
+        :rtype: Filter
+        """
+
+        objs = serialization.read_all(ser_file)
+        if len(objs) == 1:
+            return Filter(jobject=objs[0])
+        else:
+            raise Exception(
+                "Excepted one object in the model file (%s), but encountered: %d" % (ser_file, len(objs)))
+
+    def serialize(self, ser_file):
+        """
+        Serializes the filter to the specified file.
+
+        :param ser_file: the file to save the filter to
+        :type ser_file: str
+        """
+
+        serialization.write(ser_file, self)
+
 
 class MultiFilter(Filter):
     """
@@ -313,11 +343,15 @@ class StringToWordVector(Filter):
             self.jobject, "setTokenizer", "(Lweka/core/tokenizers/Tokenizer;)V", tokenizer.jobject)
 
 
-def main():
+def main(args=None):
     """
     Runs a filter from the command-line. Calls JVM start/stop automatically.
     Use -h to see all options.
+
+    :param args: the command-line arguments to use, uses sys.argv if None
+    :type args: list
     """
+
     parser = argparse.ArgumentParser(
         description='Executes a filter from the command-line. Calls JVM start/stop automatically.')
     parser.add_argument("-j", metavar="classpath", dest="classpath", help="additional classpath, jars/directories")
@@ -330,7 +364,7 @@ def main():
                         help="1-based class attribute index")
     parser.add_argument("filter", help="filter classname, e.g., weka.filters.AllFilter")
     parser.add_argument("option", nargs=argparse.REMAINDER, help="additional filter options")
-    parsed = parser.parse_args()
+    parsed = parser.parse_args(args)
     if parsed.input2 is None and parsed.output2 is not None:
         raise Exception("No second input file provided ('-r ...')!")
 
@@ -374,13 +408,31 @@ def main():
             in2.class_index = int(cls)
             out2 = flter.filter(in2)
             saver.save_file(out2, parsed.output2)
-    except Exception, e:
-        print(e)
+    except Exception:
+        print(traceback.format_exc())
     finally:
         jvm.stop()
 
+
+def sys_main():
+    """
+    Runs the main function using the system cli arguments, and
+    returns a system error code.
+
+    :return: 0 for success, 1 for failure.
+    :rtype: int
+    """
+
+    try:
+        main()
+        return 0
+    except Exception:
+        print(traceback.format_exc())
+        return 1
+
+
 if __name__ == "__main__":
     try:
         main()
-    except Exception, ex:
-        print(ex)
+    except Exception:
+        print(traceback.format_exc())
